OC.L10N.register(
    "notes",
    {
    "Notes" : "Märkmed",
    "New note" : "Uus märge",
    "Delete note" : "Kustuta märge",
    "_%n word_::_%n words_" : ["%n sõna","%n sõna"]
},
"nplurals=2; plural=(n != 1);");
